
ECG-featurizer

A python package for deriving features from ECGs


.. image:: https://readthedocs.org/projects/ECG-featurizer/badge/?version=latest
   :target: https://ECG-featurizer.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status


.. image:: https://travis-ci.org/ECG-featurizer/ECG-featurizer.svg?branch=master
   :target: https://travis-ci.org/ECG-featurizer/ECG-featurizer

.. image:: https://coveralls.io/repos/github/ECG-featurizer/ECG-featurizer/badge.svg?branch=master
   :target: https://coveralls.io/github/ECG-featurizer/ECG-featurizer?branch=master

.. image:: https://badge.fury.io/py/ECG-featurizer.svg
   :target: https://badge.fury.io/py/ECG-featurizer


.. image:: https://pypip.in/d/ECG-featurizer/badge.svg
        :target: https://pypi.python.org/pypi/ECG-featurizer/

.. image:: https://img.shields.io/github/forks/ECG-featurizer/ECG-featurizer.svg
   :alt: GitHub Forks
   :target: https://github.com/ECG-featurizer/ECG-featurizer/network

.. image:: https://img.shields.io/github/issues/ECG-featurizer/ECG-featurizer.svg
   :alt: GitHub Open Issues
   :target: https://github.com/ECG-featurizer/ECG-featurizer/issues

.. image:: http://www.repostatus.org/badges/latest/active.svg
   :alt: Project Status: Active - The project has reached a stable, usable state and is being actively developed.
   :target: http://www.repostatus.org/#active
